@@ -6,8 +6,11 @@ import os
 import logging
 import tempfile
 
-from openai_wrapper import get_openai_response
-from personalities import PERSONALITIES, get_personality, get_openai_personality
+from filegpt.openai_wrapper import get_openai_response
+from filegpt.personalities import PERSONALITIES, get_personality, get_openai_personality
+
+# from openai_wrapper import get_openai_response
+# from personalities import PERSONALITIES, get_personality, get_openai_personality
 
 import tiktoken
 from typing import List
