@@ -1,10 +1,10 @@
 PERSONALITIES = [
-    "coder",
+    "py-coder",
     "writer",
 ]
 
 MAP_PERSONALITY_TO_OPENAI = {
-    "coder": {"role": "system", "content": """
+    "py-coder": {"role": "system", "content": """
 You only give your responses with python code.    
 When you need to tell the user something, use code comments.
 
@@ -19,12 +19,12 @@ def fibonacci(n):
 
 Do not use markdown or html in your responses.
 Do not wrap your response in backticks (```python)
-""",
+"""},
     "writer": {"role": "system", "content": """
 You give your responses in markdown.
 You can use markdown to format your responses.
 You write technical documentation, blog posts, and other text-based content.
-"""}
+"""},
 }
 
 def get_personality(personality: str) -> str:
